#ifndef PLAY_HPP
#define PLAY_HPP

#include <Basis/Screen.hpp>

#include <Vector/Quat.hpp>
#include <Vector/Box.hpp>

#include <vector>

#include <ode/ode.h>

using std::vector;

const float Tick = 0.01f;

class Block {
public:
	Block() : in_stack(false), body(NULL), geom(NULL) { }

	Vector3f radius;
	Quatf orientation;
	Vector3f position;
	void draw();
	Box3f get_bounds();

	bool in_stack;

	void create_body(dWorldID world, dSpaceID space);
	void create_sphere(dWorldID world, dSpaceID space);
	void copy_body_position();
	void reset_body_position();
	void destroy_body();
	dBodyID body;
	dGeomID geom;
};

class Play : public Screen {
public:
	Play();
	virtual ~Play();
	void generate_level();
	void start_stacking();

	void start_simulation();
	void tick_simulation();
	void stop_simulation();

	dWorldID world;
	dSpaceID space;
	dGeomID ground;
	dJointGroupID collisions;
	float sim_acc;

	virtual void draw();
	virtual void update(float elapsed_time);
	virtual void handle_event(SDL_Event const &event);

	vector< Block > world_blocks;

	vector< Block > old_world_blocks;

	vector< Block > black_holes;

	bool stacking;

	Vector3f camera_at;
	Vector3f camera_target;

	Vector2f block_move;
	Vector2f camera_move;
};

#endif //PLAY_HPP
